@@ -2,7 +2,7 @@
 #'
 #' @export
 #' @param x Variety of things, character, list, or ckan_group class object
-#' @param ... Further args passed on to \code{\link{group_show}} if character given
+#' @param ... Further args passed on to [group_show()] if character given
 #' @examples \dontrun{
 #' ckanr_setup(url = "https://demo.ckan.org/", key = getOption("ckan_demo_key"))
 #'
@@ -42,7 +42,9 @@ print.ckan_group <- function(x, ...) {
   cat("  Created: ", x$created, "\n", sep = "")
 }
 
-get_group <- function(id, url = get_default_url(), key = get_default_key(), ...) {
-  res <- ckan_GET(url, 'group_show', list(id = id), key = key, ...)
+get_group <- function(id, url = get_default_url(), key = get_default_key(),
+  ...) {
+
+  res <- ckan_GET(url, 'group_show', list(id = id), key = key, opts = list(...))
   as_ck(jsl(res), "ckan_group")
 }
