@@ -1,12 +1,15 @@
 #' ckan_organization class helpers
 #'
 #' @export
-#' @param x Variety of things, character, list, or ckan_organization class object
-#' @param ... Further args passed on to \code{\link{organization_show}} if character given
+#' @param x Variety of things, character, list, or ckan_organization class
+#' object
+#' @param ... Further args passed on to [organization_show()] if character
+#' given
 #' @examples \dontrun{
-#' ckanr_setup(url = "https://demo.ckan.org/", key = getOption("ckan_demo_key"))
+#' ckanr_setup(url = "https://demo.ckan.org/",
+#' key = getOption("ckan_demo_key"))
 #'
-#' (orgs <- organization_list())
+#' (orgs <- organization_list(limit = 3))
 #' orgs[[3]]
 #'
 #' # create item class from only an item ID
@@ -25,7 +28,9 @@ as.ckan_organization.character <- function(x, ...) get_organization(x, ...)
 as.ckan_organization.ckan_organization <- function(x, ...) x
 
 #' @export
-as.ckan_organization.list <- function(x, ...) structure(x, class = "ckan_organization")
+as.ckan_organization.list <- function(x, ...) {
+  structure(x, class = "ckan_organization")
+}
 
 #' @export
 #' @rdname as.ckan_organization
@@ -40,7 +45,10 @@ print.ckan_organization <- function(x, ...) {
   cat("  No. Users: ", length(x$users), "\n", sep = "")
 }
 
-get_organization <- function(id, url = get_default_url(), key = get_default_key(), ...) {
-  res <- ckan_GET(url, 'organization_show', list(id = id), key = key, ...)
+get_organization <- function(id, url = get_default_url(),
+  key = get_default_key(), ...) {
+  
+  res <- ckan_GET(url, 'organization_show', list(id = id), key = key,
+    opts = list(...))
   as_ck(jsl(res), "ckan_organization")
 }
