@@ -1,7 +1,6 @@
 #' Datastore - search or get a dataset from CKRAN datastore
 #'
 #' @export
-#'
 #' @param sql (character) A single SQL select statement. (required)
 #' @template args
 #' @template key
@@ -12,17 +11,21 @@
 #' sql2 <- 'SELECT "Species","Genus","Family" from "f4129802-22aa-4437-b9f9-8a8f3b7b2a53" LIMIT 2'
 #' ds_search_sql(sql2, url = url, as = "table")
 #' }
-#' @importFrom httr status_code
 
 ds_search_sql <- function(sql, url = get_default_url(), key = get_default_key(),
   as = 'list', ...) {
 
-  res <- httr::GET(file.path(notrail(url), 'api/action/datastore_search_sql'), ctj(),
-              query = list(sql = sql), add_headers(Authorization = key), ...)
-  if (status_code(res) > 299) {
-    if (grepl("html", res$headers$`content-type`)) httr::stop_for_status(res)
-    stop(httr::content(res, "text", encoding = "UTF-8"))
+  con <- crul::HttpClient$new(
+    url = file.path(notrail(url), 'api/action/datastore_search_sql'),
+    headers = c(list(Authorization = key), ctj()),
+    opts = list(...)
+  )
+  res <- con$get(query = list(sql = sql))
+  if (res$status_code > 299) {
+    res$raise_for_ct_json()
+    if (grepl("html", res$response_headers$`content-type`)) res$raise_for_status()
+    stop(res$parse("UTF-8"))
   }
-  res <- httr::content(res, "text", encoding = "UTF-8")
-  switch(as, json = res, list = jsl(res), table = jsd(res))
+  txt <- res$parse("UTF-8")
+  switch(as, json = txt, list = jsl(txt), table = jsd(txt))
 }
