@@ -4,12 +4,12 @@
 #'
 #' @param id (character) Package identifier.
 #' @param include_datasets (logical) Include a list of the group's datasets.
-#'    Default: TRUE
+#' Default: `TRUE`
 #' @template args
 #' @template key
 #' @details By default the help and success slots are dropped, and only the
-#'    result slot is returned. You can request raw json with \code{as = 'json'}
-#'    then parse yourself to get the help slot.
+#' result slot is returned. You can request raw json with `as = 'json'`
+#' then parse yourself to get the help slot.
 #' @examples \dontrun{
 #' res <- group_list()
 #'
@@ -28,6 +28,6 @@ group_show <- function(id, include_datasets = TRUE, url = get_default_url(),
 
   id <- as.ckan_group(id, url = url)
   args <- cc(list(id = id$id, include_datasets = as_log(include_datasets)))
-  res <- ckan_GET(url, 'group_show', args, key = key, ...)
+  res <- ckan_GET(url, 'group_show', args, key = key, opts = list(...))
   switch(as, json = res, list = as_ck(jsl(res), "ckan_group"), table = jsd(res))
 }
