@@ -29,8 +29,9 @@
 package_activity_list <- function(id, offset = 0, limit = 31,
   url = get_default_url(), key = get_default_key(), as = "list", ...) {
 
-  id <- as.ckan_package(id, url = url)
+  id <- as.ckan_package(id, url = url, key = key)
   args <- cc(list(id = id$id, offset = offset, limit = limit))
-  res <- ckan_GET(url, 'package_activity_list', args, key = key, ...)
+  res <- ckan_GET(url, 'package_activity_list', args, key = key,
+    opts = list(...))
   switch(as, json = res, list = jsl(res), table = jsd(res))
 }
