@@ -29,6 +29,6 @@ package_revision_list <- function(id, url = get_default_url(),
   key = get_default_key(), as = "list", ...) {
 
   res <- ckan_GET(url, 'package_revision_list', list(id = id),
-    key = key, ...)
+    key = key, opts = list(...))
   switch(as, json = res, list = jsl(res), table = jsd(res))
 }
