@@ -1,7 +1,7 @@
 #' CKAN server URLS and other info
 #'
 #' @export
-#' @details Comes from the links at http://ckan.org/instances
+#' @details Comes from the links at https://ckan.org/about/instances/
 #'
 #' There were a number of other URLs for CKAN instances in the CKAN URL
 #' above, but some sites are now gone completely, or if they do exist,
@@ -141,5 +141,7 @@ server_urls <- c(
   "https://data.noaa.gov",
   "https://data.overheid.nl/data",
   "https://www.data.gv.at/katalog",
-  "https://data.nal.usda.gov"
+  "https://data.nal.usda.gov",
+  "https://data.ontario.ca/",
+  "https://ckan0.cf.opendata.inter.prod-toronto.ca/"
 )
