@@ -1,5 +1,9 @@
 context("group_list")
-u <- get_test_url()
+
+skip_on_cran()
+
+# u <- get_test_url()
+u <- "http://www.civicdata.io"
 
 test_that("group_list gives back expected class types", {
   check_ckan(u)
@@ -12,15 +16,14 @@ test_that("group_list gives back expected class types", {
 
 test_that("group_list works giving back json output", {
   check_ckan(u)
-  b <- group_list(url=u, as='json')
+  b <- group_list(url=u, as='json', limit=10)
   b_df <- jsonlite::fromJSON(b)
   expect_is(b, "character")
   expect_is(b_df, "list")
-  expect_is(b_df$result, "data.frame")
 })
 
 test_that("group_list fails correctly", {
   check_ckan(u)
-  expect_error(group_list(sort = "adf", url=u), "Cannot sort by field `adf`")
-  expect_equal(group_list(groups = 4, url=u), list())
+  expect_error(group_list(sort = "adf", url=u, limit=10), "Cannot sort by field `adf`")
+  expect_equal(group_list(groups = 4, url=u, limit=10), list())
 })
