@@ -1,15 +1,16 @@
 context("tag_show")
 
 skip_on_cran()
+skip_on_ci()
 
 u <- get_test_url()
 
 tag_test_num <- local({
-  # t <- tag_list(url=u)[[2]]$name
   t <- "api"
-  res <- httr::GET(file.path(u, paste0("dataset?tags=", t,"&_tags_limit=0")))
-  httr::stop_for_status(res)
-  html <- httr::content(res, as="text")
+  res <- crul::HttpClient$new(file.path(u, "dataset"))$get(
+    query = list(tags = t, "_tags_limit" = 0))
+  res$raise_for_status()
+  html <- res$parse("UTF-8")
   tmp <- regmatches(html, regexec("(\\d+) datasets? found", html))
   as.integer(tmp[[1]][2])
 })
